@@ -1,18 +1,22 @@
+function _aws_cdk_aws_macie_CfnAllowListProps(p) {
+    if (p == null)
+        return;
+    visitedObjects.add(p);
+    try {
+        if (!visitedObjects.has(p.tags))
+            require("@aws-cdk/core/.warnings.jsii.js")._aws_cdk_core_CfnTag(p.tags);
+    }
+    finally {
+        visitedObjects.delete(p);
+    }
+}
+function _aws_cdk_aws_macie_CfnAllowList(p) {
+}
 function _aws_cdk_aws_macie_CfnCustomDataIdentifierProps(p) {
 }
 function _aws_cdk_aws_macie_CfnCustomDataIdentifier(p) {
 }
 function _aws_cdk_aws_macie_CfnFindingsFilterProps(p) {
-    if (p == null)
-        return;
-    visitedObjects.add(p);
-    try {
-        if (!visitedObjects.has(p.findingCriteria))
-            _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty(p.findingCriteria);
-    }
-    finally {
-        visitedObjects.delete(p);
-    }
 }
 function _aws_cdk_aws_macie_CfnFindingsFilter(p) {
 }
@@ -60,4 +64,4 @@ class DeprecationError extends Error {
         });
     }
 }
-module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_macie_CfnCustomDataIdentifierProps, _aws_cdk_aws_macie_CfnCustomDataIdentifier, _aws_cdk_aws_macie_CfnFindingsFilterProps, _aws_cdk_aws_macie_CfnFindingsFilter, _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty, _aws_cdk_aws_macie_CfnSessionProps, _aws_cdk_aws_macie_CfnSession };
+module.exports = { print, getPropertyDescriptor, DeprecationError, _aws_cdk_aws_macie_CfnAllowListProps, _aws_cdk_aws_macie_CfnAllowList, _aws_cdk_aws_macie_CfnCustomDataIdentifierProps, _aws_cdk_aws_macie_CfnCustomDataIdentifier, _aws_cdk_aws_macie_CfnFindingsFilterProps, _aws_cdk_aws_macie_CfnFindingsFilter, _aws_cdk_aws_macie_CfnFindingsFilter_FindingCriteriaProperty, _aws_cdk_aws_macie_CfnFindingsFilter_FindingsFilterListItemProperty, _aws_cdk_aws_macie_CfnSessionProps, _aws_cdk_aws_macie_CfnSession };
